summaryrefslogtreecommitdiffstats
path: root/kio
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 19:10:38 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 19:10:38 -0600
commit99cc03399059853dd8699cae5752e8122cb715f1 (patch)
tree825da375ac05fc555e25b2e350504e211d85d2fb /kio
parentd5b3ae721dc072e0c70055313de9b5228b6688a8 (diff)
downloadtdelibs-99cc03399059853dd8699cae5752e8122cb715f1.tar.gz
tdelibs-99cc03399059853dd8699cae5752e8122cb715f1.zip
Rename KDEHOME and KDEDIR
Diffstat (limited to 'kio')
-rw-r--r--kio/kio/kmimemagic.h2
-rw-r--r--kio/kio/kservice.cpp2
-rw-r--r--kio/kio/kservice.h2
-rw-r--r--kio/kio/kservicetype.h2
-rw-r--r--kio/tests/ksycocatest.cpp2
-rw-r--r--kio/tests/kurifiltertest.cpp32
6 files changed, 21 insertions, 21 deletions
diff --git a/kio/kio/kmimemagic.h b/kio/kio/kmimemagic.h
index c54c94126..49fb300ad 100644
--- a/kio/kio/kmimemagic.h
+++ b/kio/kio/kmimemagic.h
@@ -82,7 +82,7 @@ protected:
*
*
* Unless specified otherwise, KMimeMagic uses
- * $KDEDIR/share/mimelnk/magic for this purpose.
+ * $TDEDIR/share/mimelnk/magic for this purpose.
*
* To make KMimeMagic restore the 'atime' of a file after it opened it,
* add its directory in kmimemagicrc like:
diff --git a/kio/kio/kservice.cpp b/kio/kio/kservice.cpp
index fb6deb27c..0c42904ee 100644
--- a/kio/kio/kservice.cpp
+++ b/kio/kio/kservice.cpp
@@ -198,7 +198,7 @@ KService::init( KDesktopFile *config )
m_strExec = config->readPathEntry( "Exec" );
if (kde4application && !m_strExec.startsWith("/")) {
- m_strExec = "KDEHOME=$HOME/.kde XDG_DATA_DIRS=/usr/share KDEDIRS=/usr/ XDG_CONFIG_DIRS=/etc/xdg/ PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/games:$PATH "+m_strExec;
+ m_strExec = "TDEHOME=$HOME/.kde XDG_DATA_DIRS=/usr/share TDEDIRS=/usr/ XDG_CONFIG_DIRS=/etc/xdg/ PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/games:$PATH "+m_strExec;
} else if (config->readBoolEntry("X-KDE-SubstituteUID")) {
int space = m_strExec.find(" ");
if (space==-1)
diff --git a/kio/kio/kservice.h b/kio/kio/kservice.h
index c276e8369..92a5b3005 100644
--- a/kio/kio/kservice.h
+++ b/kio/kio/kservice.h
@@ -165,7 +165,7 @@ public:
* is stored.
*
* This is a relative path if the desktop entry was found in any
- * of the locations pointed to by $KDEDIRS (e.g. "Internet/kppp.desktop")
+ * of the locations pointed to by $TDEDIRS (e.g. "Internet/kppp.desktop")
* It is a full path if the desktop entry originates from another
* location.
* @return the path of the service's desktop file,
diff --git a/kio/kio/kservicetype.h b/kio/kio/kservicetype.h
index 27624e50b..b96984d43 100644
--- a/kio/kio/kservicetype.h
+++ b/kio/kio/kservicetype.h
@@ -39,7 +39,7 @@
* instead of a type of file.
* For instance, KOfficeFilter is a service type.
* It is associated to services according to the user profile (kuserprofile.h).
- * Service types are stored as desktop files in $KDEHOME/share/servicetypes.
+ * Service types are stored as desktop files in $TDEHOME/share/servicetypes.
* @see KService
*/
class KIO_EXPORT KServiceType : public KSycocaEntry
diff --git a/kio/tests/ksycocatest.cpp b/kio/tests/ksycocatest.cpp
index a9fa8198a..ab0130860 100644
--- a/kio/tests/ksycocatest.cpp
+++ b/kio/tests/ksycocatest.cpp
@@ -193,7 +193,7 @@ int main(int argc, char *argv[])
//
- debug("\nTrying findByURL for $KDEDIR/bin/kdesktop");
+ debug("\nTrying findByURL for $TDEDIR/bin/kdesktop");
KMimeType::Ptr mf = KMimeType::findByURL( KStandardDirs::findExe( "kdesktop" ), 0,
true, false );
assert( mf );
diff --git a/kio/tests/kurifiltertest.cpp b/kio/tests/kurifiltertest.cpp
index 9f4477e5e..4e9f9ad2d 100644
--- a/kio/tests/kurifiltertest.cpp
+++ b/kio/tests/kurifiltertest.cpp
@@ -154,8 +154,8 @@ static const KCmdLineOptions options[] =
int main(int argc, char **argv)
{
// Ensure that user configuration doesn't change the results of those tests
- // KDEHOME needs to be writable though, for a ksycoca database
- setenv( "KDEHOME", TQFile::encodeName( TQDir::homeDirPath() + "/.kde-kurifiltertest" ), true );
+ // TDEHOME needs to be writable though, for a ksycoca database
+ setenv( "TDEHOME", TQFile::encodeName( TQDir::homeDirPath() + "/.kde-kurifiltertest" ), true );
setenv( "KDE_FORK_SLAVES", "yes", true ); // simpler, for the final cleanup
KAboutData aboutData(appName, programName, version, description);
@@ -214,7 +214,7 @@ int main(int argc, char **argv)
// ShortURI/LocalDomain filter tests. NOTE: any of these tests can fail
// if you have specified your own patterns in kshorturifilterrc. For
- // examples, see $KDEDIR/share/config/kshorturifilterrc .
+ // examples, see $TDEDIR/share/config/kshorturifilterrc .
filter( "linuxtoday.com", "http://linuxtoday.com", KURIFilterData::NET_PROTOCOL );
filter( "LINUXTODAY.COM", "http://linuxtoday.com", KURIFilterData::NET_PROTOCOL );
filter( "kde.org", "http://kde.org", KURIFilterData::NET_PROTOCOL );
@@ -290,7 +290,7 @@ int main(int argc, char **argv)
TQCString qtdir=getenv("QTDIR");
TQCString home = getenv("HOME");
- TQCString kdehome = getenv("KDEHOME");
+ TQCString kdehome = getenv("TDEHOME");
filter( "$SOMEVAR/tdelibs/kio", 0, KURIFilterData::ERROR ); // note: this dir doesn't exist...
filter( "$ETC/passwd", "/etc/passwd", KURIFilterData::LOCAL_FILE );
@@ -301,31 +301,31 @@ int main(int argc, char **argv)
if (kdehome.isEmpty())
{
kdehome += "$HOME/.kde";
- setenv("KDEHOME", kdehome.data(), 0);
+ setenv("TDEHOME", kdehome.data(), 0);
}
- filter( "$KDEHOME/share", kdehome+"/share", KURIFilterData::LOCAL_DIR );
+ filter( "$TDEHOME/share", kdehome+"/share", KURIFilterData::LOCAL_DIR );
KStandardDirs::makeDir( kdehome+"/a+plus" );
- filter( "$KDEHOME/a+plus", kdehome+"/a+plus", KURIFilterData::LOCAL_DIR );
+ filter( "$TDEHOME/a+plus", kdehome+"/a+plus", KURIFilterData::LOCAL_DIR );
// BR 27788
KStandardDirs::makeDir( kdehome+"/share/Dir With Space" );
- filter( "$KDEHOME/share/Dir With Space", kdehome+"/share/Dir With Space", KURIFilterData::LOCAL_DIR );
+ filter( "$TDEHOME/share/Dir With Space", kdehome+"/share/Dir With Space", KURIFilterData::LOCAL_DIR );
// support for name filters (BR 93825)
- filter( "$KDEHOME/*.txt", kdehome+"/*.txt", KURIFilterData::LOCAL_DIR );
- filter( "$KDEHOME/[a-b]*.txt", kdehome+"/[a-b]*.txt", KURIFilterData::LOCAL_DIR );
- filter( "$KDEHOME/a?c.txt", kdehome+"/a?c.txt", KURIFilterData::LOCAL_DIR );
- filter( "$KDEHOME/?c.txt", kdehome+"/?c.txt", KURIFilterData::LOCAL_DIR );
+ filter( "$TDEHOME/*.txt", kdehome+"/*.txt", KURIFilterData::LOCAL_DIR );
+ filter( "$TDEHOME/[a-b]*.txt", kdehome+"/[a-b]*.txt", KURIFilterData::LOCAL_DIR );
+ filter( "$TDEHOME/a?c.txt", kdehome+"/a?c.txt", KURIFilterData::LOCAL_DIR );
+ filter( "$TDEHOME/?c.txt", kdehome+"/?c.txt", KURIFilterData::LOCAL_DIR );
// but let's check that a directory with * in the name still works
KStandardDirs::makeDir( kdehome+"/share/Dir*With*Stars" );
- filter( "$KDEHOME/share/Dir*With*Stars", kdehome+"/share/Dir*With*Stars", KURIFilterData::LOCAL_DIR );
+ filter( "$TDEHOME/share/Dir*With*Stars", kdehome+"/share/Dir*With*Stars", KURIFilterData::LOCAL_DIR );
KStandardDirs::makeDir( kdehome+"/share/Dir?QuestionMark" );
- filter( "$KDEHOME/share/Dir?QuestionMark", kdehome+"/share/Dir?QuestionMark", KURIFilterData::LOCAL_DIR );
+ filter( "$TDEHOME/share/Dir?QuestionMark", kdehome+"/share/Dir?QuestionMark", KURIFilterData::LOCAL_DIR );
KStandardDirs::makeDir( kdehome+"/share/Dir[Bracket" );
- filter( "$KDEHOME/share/Dir[Bracket", kdehome+"/share/Dir[Bracket", KURIFilterData::LOCAL_DIR );
+ filter( "$TDEHOME/share/Dir[Bracket", kdehome+"/share/Dir[Bracket", KURIFilterData::LOCAL_DIR );
- filter( "$HOME/$KDEDIR/tdebase/kcontrol/ebrowsing", 0, KURIFilterData::ERROR );
+ filter( "$HOME/$TDEDIR/tdebase/kcontrol/ebrowsing", 0, KURIFilterData::ERROR );
filter( "$1/$2/$3", "http://www.google.com/search?q=$1/$2/$3&ie=UTF-8&oe=UTF-8", KURIFilterData::NET_PROTOCOL ); // can be used as bogus or valid test. Currently triggers default search, i.e. google
filter( "$$$$", "http://www.google.com/search?q=$$$$&ie=UTF-8&oe=UTF-8", KURIFilterData::NET_PROTOCOL ); // worst case scenarios.